summaryrefslogtreecommitdiff
path: root/framework/Web/UI/ActiveControls/TBaseActiveControl.php
diff options
context:
space:
mode:
authorwei <>2006-08-29 12:53:23 +0000
committerwei <>2006-08-29 12:53:23 +0000
commit2db708960f4435e2b98518f8fa84cc036ac9f2eb (patch)
tree6dc4ae8a624bf2afeaadfbed5be81cdd8c1b0ffe /framework/Web/UI/ActiveControls/TBaseActiveControl.php
parentf0a6fad58f8eae14554443081ffb166aaf71762a (diff)
Update active controls.
Diffstat (limited to 'framework/Web/UI/ActiveControls/TBaseActiveControl.php')
-rw-r--r--framework/Web/UI/ActiveControls/TBaseActiveControl.php4
1 files changed, 3 insertions, 1 deletions
diff --git a/framework/Web/UI/ActiveControls/TBaseActiveControl.php b/framework/Web/UI/ActiveControls/TBaseActiveControl.php
index e5fe8f16..ed2e50db 100644
--- a/framework/Web/UI/ActiveControls/TBaseActiveControl.php
+++ b/framework/Web/UI/ActiveControls/TBaseActiveControl.php
@@ -119,13 +119,15 @@ class TBaseActiveControl extends TComponent
/**
* Returns true if callback response is allowed to update the browser contents.
* Is is true if the control is initilized, and is a callback request and
* the {@link setEnableUpdate EnabledUpdate} property is true.
* @return boolean true if the callback response is allowed update
* client-side contents.
*/
public function canUpdateClientSide()
{
return $this->getControl()->getHasChildInitialized()
+ && $this->getPage()->getIsLoadingPostData() == false
&& $this->getPage()->getIsCallback()
&& $this->getEnableUpdate();
}
@@ -119,13 +119,15 @@ class TBaseActiveControl extends TComponent
* Returns true if callback response is allowed to update the browser contents.
* Is is true if the control is initilized, and is a callback request and
- * the {@link setEnableUpdate EnabledUpdate} property is true.
+ * the {@link setEnableUpdate EnabledUpdate} property is true and
+ * the page is not loading post data.
* @return boolean true if the callback response is allowed update
* client-side contents.